/*
 * Auto-Generated File. Changes will be destroyed.
 */
#include "squid.h"
#include "icp_opcode.h"

const char * icp_opcode_str[] = {
	"ICP_INVALID",
	"ICP_QUERY",
	"ICP_HIT",
	"ICP_MISS",
	"ICP_ERR",
	"ICP_SEND",
	"ICP_SENDA",
	"ICP_DATABEG",
	"ICP_DATA",
	"ICP_DATAEND",
	"ICP_SECHO",
	"ICP_DECHO",
	"ICP_NOTIFY",
	"ICP_INVALIDATE",
	"ICP_DELETE",
	"ICP_UNUSED15",
	"ICP_UNUSED16",
	"ICP_UNUSED17",
	"ICP_UNUSED18",
	"ICP_UNUSED19",
	"ICP_UNUSED20",
	"ICP_MISS_NOFETCH",
	"ICP_DENIED",
	"ICP_HIT_OBJ",
	"ICP_END"
};
