/*
 * Auto-Generated File. Changes will be destroyed.
 */
#include "squid.h"
#include "error/forward.h"

const char * err_type_str[] = {
	"ERR_NONE",
	"ERR_ACCESS_DENIED",
	"ERR_CACHE_ACCESS_DENIED",
	"ERR_CACHE_MGR_ACCESS_DENIED",
	"ERR_FORWARDING_DENIED",
	"ERR_NO_RELAY",
	"ERR_CANNOT_FORWARD",
	"ERR_READ_TIMEOUT",
	"ERR_LIFETIME_EXP",
	"ERR_READ_ERROR",
	"ERR_WRITE_ERROR",
	"ERR_CONNECT_FAIL",
	"ERR_SECURE_CONNECT_FAIL",
	"ERR_SOCKET_FAILURE",
	"ERR_DNS_FAIL",
	"ERR_URN_RESOLVE",
	"ERR_ONLY_IF_CACHED_MISS",
	"ERR_TOO_BIG",
	"ERR_INVALID_RESP",
	"ERR_UNSUP_HTTPVERSION",
	"ERR_INVALID_REQ",
	"ERR_UNSUP_REQ",
	"ERR_INVALID_URL",
	"ERR_ZERO_SIZE_OBJECT",
	"ERR_PRECONDITION_FAILED",
	"ERR_CONFLICT_HOST",
	"ERR_FTP_DISABLED",
	"ERR_FTP_UNAVAILABLE",
	"ERR_FTP_FAILURE",
	"ERR_FTP_PUT_ERROR",
	"ERR_FTP_NOT_FOUND",
	"ERR_FTP_FORBIDDEN",
	"ERR_FTP_PUT_CREATED",
	"ERR_FTP_PUT_MODIFIED",
	"ERR_ESI",
	"ERR_ICAP_FAILURE",
	"ERR_GATEWAY_FAILURE",
	"ERR_DIR_LISTING",
	"ERR_SQUID_SIGNATURE",
	"ERR_SHUTTING_DOWN",
	"ERR_PROTOCOL_UNKNOWN",
	"TCP_RESET",
	"ERR_CLIENT_GONE",
	"ERR_SECURE_ACCEPT_FAIL",
	"ERR_REQUEST_START_TIMEOUT",
	"ERR_REQUEST_PARSE_TIMEOUT",
	"ERR_RELAY_REMOTE",
	"MGR_INDEX",
	"ERR_MAX",
	
};
